Exception: Tomo::Configuration::UnspecifiedEnvironmentError
- Inherits:
-
Error
- Object
- StandardError
- Error
- Tomo::Configuration::UnspecifiedEnvironmentError
- Defined in:
- lib/tomo/configuration/unspecified_environment_error.rb
Instance Attribute Summary collapse
-
#environments ⇒ Object
Returns the value of attribute environments.
Instance Method Summary collapse
Methods inherited from Error
Methods included from Tomo::Colors
Instance Attribute Details
#environments ⇒ Object
Returns the value of attribute environments.
6 7 8 |
# File 'lib/tomo/configuration/unspecified_environment_error.rb', line 6 def environments @environments end |
Instance Method Details
#to_console ⇒ Object
8 9 10 11 12 13 14 15 16 17 18 19 |
# File 'lib/tomo/configuration/unspecified_environment_error.rb', line 8 def to_console <<~ERROR No environment specified. This is a multi-environment project. To run a remote task you must specify which environment to use by including the #{blue('-e')} option. Run tomo again with one of these options to specify the environment: #{} ERROR end |